@@ -392,10 +392,9 @@ class FOFStrategyType(ReadableEnum):
     S6 = 6                  # 宏观对冲
     S7 = 7                  # 高频套利
     S8 = 8                  # 债券策略
-    S9 = 9                  # 期权策略
     S10 = 10                # 组合策略
-    S11 = 11                # 其他
-    S12 = 12                # 股票中性
+    S11 = 11                # 股票多空
+    S12 = 12                # 其他（期权等）
 
 
 class FOFRiskType(ReadableEnum):
@@ -412,3 +411,10 @@ class DividendCalcMethod(ReadableEnum):
 
     BY_TOTAL_AMOUNT = 1  # 红利总额
     BY_PER_UNIT = 2  # 每单位红利
+
+
+class EMailParserType(ReadableEnum):
+    ''' 电子邮件 parser 类型'''
+
+    E_PARSER_NAV = 1  # 净值邮件
+    E_PARSER_VALUATION = 2  # 估值邮件
