@@ -108,17 +108,15 @@ class PortfolioDataApi(metaclass=Singleton):
 
     def get_all_fund_info(self, fund_list=None):
         try:
-            if fund_list is not None:
-                mutual_fund_list = [_ for _ in fund_list if '!' in _]
-                hedge_fund_list = [_ for _ in fund_list if '!' not in _]
+            mutual_fund_list = [_ for _ in fund_list if '!' in _]
+            hedge_fund_list = [_ for _ in fund_list if '!' not in _]
+            mutual_fund_info = pd.DataFrame()
+            hedge_fund_info = pd.DataFrame()
+            if len(mutual_fund_list) > 0:
                 mutual_fund_info = BasicDataApi().get_fund_info(fund_list=mutual_fund_list)[['fund_id','desc_name']]
-                hedge_fund_info = RawDataApi().get_hf_fund_info(fund_list=hedge_fund_list)[['fund_id','desc_name']]
-            else:
-                mutual_fund_info = BasicDataApi().get_fund_info()[['fund_id','desc_name']]
-                hedge_fund_info = RawDataApi().get_hf_fund_info()[['fund_id','desc_name']]
-            if not mutual_fund_info.empty:
                 mutual_fund_info.loc[:,'fund_type'] = '公募'    
-            if not hedge_fund_info.empty:
+            if len(hedge_fund_list) > 0:
+                hedge_fund_info = RawDataApi().get_hf_fund_info(fund_list=hedge_fund_list)[['fund_id','desc_name']]
                 hedge_fund_info.loc[:,'fund_type'] = '私募'
             df_list = [i for i in [mutual_fund_info, hedge_fund_info] if not i.empty ]
             fund_info = pd.concat(df_list)
@@ -211,6 +209,7 @@ class PortfolioDataApi(metaclass=Singleton):
         try:
             order_list, fund_type = self.trade_history_parse(trade_history)
             fund_list = set(list([j for dic in order_list for i in dic.values() for j in i.keys()]))
+            hf_fund_con = any(['!' not in _fund_id for _fund_id in fund_list])
             _begin_date = min([j for i in order_list for j in i.keys()])
             fund_nav = self.get_all_fund_nav(start_date=_begin_date,fund_list=fund_list)
             if fund_nav.empty:
@@ -264,6 +263,15 @@ class PortfolioDataApi(metaclass=Singleton):
                 port_type_result.append(fund_type_amt_dt)
             port_mv_result = [i.iloc[:-1] if i.index[-1] != port_mv_result[-1].index[-1] else i for i in port_mv_result]
             port_mv_result = pd.concat(port_mv_result)
+            if hf_fund_con:
+                port_mv_result = CalculatorBase.data_resample_weekly_nav(port_mv_result, rule='W-FRI').dropna()
+                today = datetime.datetime.today().date()
+                yesterday = today - datetime.timedelta(days=1)
+                if port_mv_result.index[-1] > today:
+                    id_list = port_mv_result.index.tolist()
+                    id_list[-1] = yesterday
+                    port_mv_result.index = id_list
+
             port_mv_result = port_mv_result.reindex(pd.date_range(start=port_mv_result.index[0], end=port_mv_result.index[-1]))
             port_mv_result.index = [i.date() for i in port_mv_result.index]
             port_mv_result.index.name = 'datetime'
@@ -308,7 +316,7 @@ class PortfolioDataApi(metaclass=Singleton):
             print(f'Failed to get data <err_msg> {e} from portfolio.get_portfolio_benchmark_info')
             return []
 
-    def get_portfolio_mv(self, fund_nav, index_id, begin_date, end_date, time_para):
+    def get_portfolio_mv(self, fund_nav, index_id, begin_date, end_date, time_para, trade_history):
         try:
             if fund_nav.empty:
                 df = pd.DataFrame()
@@ -323,12 +331,14 @@ class PortfolioDataApi(metaclass=Singleton):
             fund_nav = fund_nav.dropna()
             fund_nav.columns=['组合']
             basic = BasicDataApi()
-            # TODO if change asset_price
-            index_price = basic.get_index_price_dt(index_list=[index_id],start_date=fund_nav.index[0] - datetime.timedelta(days=10),end_date=fund_nav.index[-1]).pivot_table(index='datetime',columns='index_id',values='close')
-            index_info = basic.get_index_info([index_id])
-            name_dic = index_info.set_index('index_id').to_dict()['desc_name']
+            order_list, fund_type = self.trade_history_parse(trade_history)
+            fund_list = set(list([j for dic in order_list for i in dic.values() for j in i.keys()]))
+            hf_fund_con = any(['!' not in _fund_id for _fund_id in fund_list])
+            frequency = '1W' if hf_fund_con else '1D'
+            index_price = basic.get_index_and_asset_price(index_list=[index_id],begin_date=fund_nav.index[0], end_date=fund_nav.index[-1])
+            name_dic = basic.get_index_and_asset_name_dic([index_id])
             begin_date, end_date = RawDataApi().get_date_range(time_para, begin_date, end_date)
-            df = pd.merge(fund_nav.reset_index(), index_price.reset_index(),how='outer').set_index('datetime').sort_index().ffill().dropna()
+            df = pd.merge(fund_nav.reset_index(), index_price.reset_index(),how='outer').set_index('datetime').sort_index().ffill().dropna().reindex(fund_nav.index)
             df = df.loc[begin_date:end_date]
             df = df / df.iloc[0]
             df.loc[:,'价格比'] = df.组合 / df[index_id]
@@ -344,7 +354,7 @@ class PortfolioDataApi(metaclass=Singleton):
             mdd2_d1 = str(mdd_details['mdd2_d1'])
             mdd2_d2 = str(mdd_details['mdd2_d2'])
             mdd2_lens = mdd_details['mdd2_len']
-            bk_stats = Calculator.get_stat_result_from_df(df=mv_df.reset_index(), date_column='date', value_column='mv').__dict__
+            bk_stats = Calculator.get_stat_result_from_df(df=mv_df.reset_index(), date_column='date', value_column='mv', frequency=frequency).__dict__
             ar = print_st(bk_stats['annualized_ret'])
             av = print_st(bk_stats['annualized_vol'])
             r_mdd = print_st(bk_stats['recent_drawdown'])
@@ -452,18 +462,20 @@ class PortfolioDataApi(metaclass=Singleton):
             data['收益'].index.name = 'datetime'
             return data
 
-    def get_portfolio_stats(self, fund_nav, index_id):
+    def get_portfolio_stats(self, fund_nav, index_id, trade_history):
         try:
             if fund_nav.empty:
                 return None
             fund_nav = fund_nav.dropna()
             fund_nav.columns=['组合']
+            order_list, fund_type = self.trade_history_parse(trade_history)
+            fund_list = set(list([j for dic in order_list for i in dic.values() for j in i.keys()]))
+            hf_fund_con = any(['!' not in _fund_id for _fund_id in fund_list])
+            frequency = '1W' if hf_fund_con else '1D'
             basic = BasicDataApi()
-            # TODO if change asset_price
-            index_price = basic.get_index_price_dt(index_list=[index_id],start_date=fund_nav.index[0] - datetime.timedelta(days=10),end_date=fund_nav.index[-1]).pivot_table(index='datetime',columns='index_id',values='close')
-            index_info = basic.get_index_info([index_id])
-            name_dic = index_info.set_index('index_id').to_dict()['desc_name']
-            df = pd.merge(fund_nav.reset_index(), index_price.reset_index(),how='outer').set_index('datetime').sort_index().ffill().dropna()
+            index_price = basic.get_index_and_asset_price(index_list=[index_id],begin_date=fund_nav.index[0], end_date=fund_nav.index[-1])
+            name_dic = basic.get_index_and_asset_name_dic([index_id])
+            df = pd.merge(fund_nav.reset_index(), index_price.reset_index(),how='outer').set_index('datetime').sort_index().ffill().dropna().reindex(fund_nav.index)
             df = df / df.iloc[0]
             df = df.rename(columns=name_dic)
             result = []
@@ -471,7 +483,7 @@ class PortfolioDataApi(metaclass=Singleton):
                 res_status = Calculator.get_benchmark_stat_result(dates=df.index,
                                                                 values=df[col],
                                                                 benchmark_values=df[name_dic[index_id]],
-                                                                frequency = '1D',
+                                                                frequency = frequency,
                                                                 risk_free_rate=0.025, )
                 
                 indicators_tem={
@@ -615,9 +627,7 @@ class PortfolioDataApi(metaclass=Singleton):
                 }
                 return data
             fund_nav = fund_nav.ffill()
-            # TODO if change asset_price
-            index_price = basic.get_index_price(index_list=[index_id])
-            index_price = index_price.pivot_table(columns='index_id',index='datetime',values='close')
+            index_price = basic.get_index_and_asset_price(index_list=[index_id],begin_date=fund_nav.index[0], end_date=fund_nav.index[-1])
             nav_df = fund_nav.join(index_price).ffill().dropna()
             
             result = []
@@ -636,7 +646,7 @@ class PortfolioDataApi(metaclass=Singleton):
                     is_empty = False
                 elif not is_empty and r[1] == 0:
                     dic['end_date'] = r[0]
-                    dic['rise'] =  bool(nav_df.loc[:dic['end_date']].iloc[-1][fund_id] > nav_df.loc[dic['begin_date'],fund_id])
+                    dic['rise'] =  bool(nav_df.loc[:dic['end_date']].iloc[-1][fund_id] > nav_df.loc[dic['begin_date']:,fund_id].values[0])
                     dic['begin_date'] = str(dic['begin_date'])
                     dic['end_date'] = str(dic['end_date'])
                     result.append(dic)
@@ -644,7 +654,7 @@ class PortfolioDataApi(metaclass=Singleton):
                     is_empty = True
             if not is_empty:
                 dic['end_date'] = end_date
-                dic['rise'] =  bool(nav_df.loc[:dic['end_date']].iloc[-1][fund_id] > nav_df.loc[dic['begin_date'],fund_id])
+                dic['rise'] =  bool(nav_df.loc[:dic['end_date']].iloc[-1][fund_id] > nav_df.loc[dic['begin_date']:,fund_id].values[0])
                 dic['begin_date'] = str(dic['begin_date'])
                 dic['end_date'] = str(dic['end_date'])
                 result.append(dic)
@@ -843,7 +853,16 @@ class PortfolioDataApi(metaclass=Singleton):
             return data
 
     def get_port_rolling_beta_index_info(self):
-        return [['hs300','沪深300'],['csi500','中证500']] 
+        try:
+            index_info = BasicDataApi().get_asset_info_real(real_id_list=['hs300','csi500'])
+            res = []
+            for r in index_info.itertuples():
+                res.append([r.asset_id, r.real_name])
+            return res
+        
+        except Exception as e:
+            print(f'Failed to get data <err_msg> {e} from portfolio.get_port_rolling_beta_index_info')
+            return []
 
     def get_port_fund_alpha_detail(self, trade_history, benchmark_id_info): 
         try:
@@ -856,17 +875,11 @@ class PortfolioDataApi(metaclass=Singleton):
             
             dts_list = [j for i in order_list for j in i.keys()] + [fund_nav.index[-1]]
             dts_list = [[i,dts_list[dts_list.index(i)+1]] for i in dts_list if i != dts_list[-1]]
-
-            # TODO if change asset_price
-            index_price = BasicDataApi().get_index_price_dt(index_list=list(benchmark_id_info.values()),
-                                                            start_date=fund_nav.index[0],
-                                                            end_date=fund_nav.index[-1],
-                                                        )
-            index_price = index_price.pivot_table(index='datetime',columns='index_id',values='close').ffill()
+            basic = BasicDataApi()
+            index_price = basic.get_index_and_asset_price(index_list=list(benchmark_id_info.values()),begin_date=fund_nav.index[0], end_date=fund_nav.index[-1])
             fund_info = self.get_all_fund_info(fund_list=fund_nav.columns.tolist())
             fund_desc_dic = fund_info.set_index('fund_id')['desc_name'].to_dict()
-            index_info = BasicDataApi().get_index_info(index_list=list(benchmark_id_info.values()))
-            index_desc_dic = index_info.set_index('index_id')['desc_name'].to_dict()
+            index_desc_dic = basic.get_index_and_asset_name_dic(list(benchmark_id_info.values()))
             result = {}
             for fund_ti,_fund_list in fund_type.items():
                 _result = []
@@ -934,7 +947,7 @@ class PortfolioDataApi(metaclass=Singleton):
             dts_list = [begin_date] + exchange_list[exchange_list>begin_date].tolist() + [end_date]
             date_pairs = [[dt, dts_list[idx+1]] for idx, dt in enumerate(dts_list) if dt != dts_list[-1]]
 
-            port_nav = PortfolioDataApi().get_portfolio_mv(fund_nav=fund_nav, index_id=index_id,begin_date=begin_date,end_date=end_date,time_para=time_para)
+            port_nav = PortfolioDataApi().get_portfolio_mv(fund_nav=fund_nav, index_id=index_id,begin_date=begin_date,end_date=end_date,time_para=time_para,trade_history=trade_history)
             fund_info = self.get_all_fund_info(fund_list = result['各基净值'].columns.tolist())
             fund_desc_dic = fund_info.set_index('fund_id')['desc_name'].to_dict()
             fund_type_dic = { vi: k for k, v in fund_type.items() for vi in v}
@@ -947,9 +960,7 @@ class PortfolioDataApi(metaclass=Singleton):
 
             _index_price = result['大类净值'].loc[begin_date:]
             benchmark_id_info_r = {v: k for k, v in benchmark_id_info.items()}
-            # TODO if change asset_price
-            index_price = BasicDataApi().get_index_price_dt(index_list=list(benchmark_id_info.values()),start_date=begin_date,end_date=end_date)
-            index_price = index_price.pivot_table(columns='index_id',values='close',index='datetime')
+            index_price = BasicDataApi().get_index_and_asset_price(index_list=list(benchmark_id_info.values()),begin_date=fund_nav.index[0], end_date=fund_nav.index[-1])
             index_price = index_price.rename(columns=benchmark_id_info_r)
             index_price = index_price.reindex(_index_price.index)
             result_2 = _index_price / _index_price.iloc[0] / (index_price / index_price.iloc[0])
@@ -1108,3 +1119,4 @@ class PortfolioDataApi(metaclass=Singleton):
                 }
             
 
+
