@@ -84,9 +84,11 @@ class FundDailyCollectionProcessor(object):
 
     def get_fund_benchmark_df(self):
         def select_one_benchmark(x):
-            if not x:
+            if x is None:
                 return None
             x = json.loads(x)
+            if not x:
+                return
 
             # 特殊常数处理
             if x.get('1'):
@@ -545,14 +547,14 @@ class FundDailyCollectionProcessor(object):
                 'mng_name':'top_mng_name',
                 'profit':'top_manager_profit',
                 'mng_id':'top_mng_id'
-            }   
+            }
+            fund_recommend_extend = fund_recommend_extend[fund_recommend_extend.mng_id.notna()]
             fund_recommend_extend = fund_recommend_extend.set_index(['fund_id','mng_id']).join(_manager_info.set_index(['fund_id','mng_id'])).reset_index().rename(columns=_col).set_index('fund_id')
             funds = funds.drop(columns=['manage_fee','trustee_fee'])
             exchange_status = self.get_exchange_status_df().set_index('fund_id')
             print(exchange_status)
             print('-' * 100)
 
-            
             print('处理机构评级')
             rating = self.get_institution_rating_df()
             rating = rating.drop_duplicates(subset=['fund_id'], keep='last')
