@@ -19,14 +19,14 @@ from ...util.aip_calc import xirr
 from ...constant import HoldingAssetType, FOFTradeStatus
 from ..api.basic import BasicDataApi
 from ..api.derived import DerivedDataApi
-from ..view.basic_models import HedgeFundInfo, FOFInfo, HedgeFundNAV, FOFInvestorPosition, FOFInvestorPositionSummary
+from ..view.basic_models import FOFInfo, HedgeFundNAV, FOFInvestorPosition, FOFInvestorPositionSummary
 from ..view.derived_models import FOFNav, FOFNavCalc, FOFPosition, FOFInvestorData, FOFPositionDetail
 from ..wrapper.mysql import BasicDatabaseConnector, DerivedDatabaseConnector
 from ..nav_reader.hedge_fund_nav_reader import HedgeFundNAVReader
 from .manager_hedge_fund import HedgeFundDataManager
 
 
-class FOFDataManagerLite():
+class FOFDataManagerLite:
 
     _DAYS_PER_YEAR_FOR_INTEREST = 360
 
@@ -87,14 +87,14 @@ class FOFDataManagerLite():
     @staticmethod
     def _calc_virtual_net_value(manager_id, fof_id, fund_list, asset_allocation=None):
         '''计算虚拟净值'''
-        fund_info = FOFDataManagerLite.get_hedge_fund_info(fund_list)
+        fund_info = BasicDataApi().get_fof_info(manager_id, fund_list)
         # TODO: 目前只支持高水位法计算
         fund_info = fund_info.loc[fund_info.incentive_fee_mode == '高水位法']
-        fund_info = fund_info.set_index('fund_id')
-        incentive_fee_ratio = fund_info['incentive_fee_ratio'].to_dict()
-        v_nav_decimals = fund_info['v_nav_decimals'].to_dict()
+        fund_info = fund_info.set_index('fof_id')
+        incentive_fee_ratio = fund_info['incentive_fee_str'].to_dict()
+        v_nav_decimals = fund_info['nav_decimals'].to_dict()
 
-        df = DerivedDataApi().get_fof_nav(manager_id, fund_list)
+        df = FOFDataManagerLite.get_fof_nav(manager_id, fund_list)
         df = df.rename(columns={'fof_id': 'fund_id'})
         df = df[df.fund_id.isin(fund_info.index.array)]
 
@@ -136,7 +136,8 @@ class FOFDataManagerLite():
             df = pd.DataFrame(datas_to_calc_v[row.fund_id], columns=['fund_id', 'datetime', 'unit_total', 'water_line'])
             if df.empty:
                 continue
-            v_nav = FOFDataManagerLite._do_calc_v_net_value(row.nav, df.unit_total.iloc[[-1]], row.acc_net_value, df.water_line.iloc[[-1]], incentive_fee_ratio[row.fund_id], v_nav_decimals[row.fund_id])
+            # TODO: 处理不是简单字符串的业绩报酬比例
+            v_nav = FOFDataManagerLite._do_calc_v_net_value(row.nav, df.unit_total, row.acc_net_value, df.water_line, float(incentive_fee_ratio[row.fund_id]), v_nav_decimals[row.fund_id])
             v_nav_result.append({'datetime': row.Index, 'fund_id': row.fund_id, 'v_nav': v_nav})
         df = pd.DataFrame.from_dict(v_nav_result)
         if not df.empty:
@@ -167,7 +168,7 @@ class FOFDataManagerLite():
     def _calc_adjusted_net_value(manager_id: str, fund_list: List[str]):
         '''计算复权净值'''
 
-        df = DerivedDataApi().get_fof_nav(manager_id, fund_list)
+        df = FOFDataManagerLite.get_fof_nav(manager_id, fund_list)
         return df.groupby(by='fof_id', sort=False).apply(FOFDataManagerLite._calc_adj_nav_for_a_fund)
 
     def _init(self, manager_id: str, fof_id: str, debug_mode=False):
@@ -191,7 +192,7 @@ class FOFDataManagerLite():
         if debug_mode:
             print(f'fof info: (manager_id){manager_id} (fof_id){fof_id} (management_fee){self._MANAGEMENT_FEE_PER_YEAR} (custodian_fee){self._CUSTODIAN_FEE_PER_YEAR} '
                   f'(admin_service_fee){self._ADMIN_SERVICE_FEE_PER_YEAR} (current_deposit_rate){self._DEPOSIT_INTEREST_PER_YEAR} (subscription_fee){self._SUBSCRIPTION_FEE} '
-                  f'(incentive_fee_mode){self._INCENTIVE_FEE_MODE} (established_date){self._ESTABLISHED_DATE})')
+                  f'(incentive_fee_mode){self._INCENTIVE_FEE_MODE} (established_date){self._ESTABLISHED_DATE}')
 
         # 获取FOF份额变化信息
         fof_scale = DerivedDataApi().get_hedge_fund_investor_pur_redemp(manager_id, [fof_id])
@@ -236,7 +237,7 @@ class FOFDataManagerLite():
         # 获取私募基金净值数据
         if self._hedge_pos is not None:
             hedge_fund_list = list(self._hedge_pos.columns.unique())
-            hedge_fund_nav = DerivedDataApi().get_fof_nav(manager_id, hedge_fund_list)
+            hedge_fund_nav = FOFDataManagerLite.get_fof_nav(manager_id, hedge_fund_list)
             hedge_fund_nav = hedge_fund_nav.pivot(index='datetime', columns='fof_id').reindex(index=self._date_list)
             # self._hedge_nav = hedge_fund_nav['v_net_value']
             self._all_latest_nav = hedge_fund_nav['nav'].ffill().iloc[-1, :]
@@ -326,6 +327,7 @@ class FOFDataManagerLite():
         administrative_fee_list = pd.Series(dtype='float64', name='administrative_fee')
         deposit_interest_list = pd.Series(dtype='float64', name='interest')
         positions_list = pd.Series(dtype='float64', name='position')
+        position_details = {}
         # investor_pos_list = []
         for date in self._date_list:
             total_amount = 0
@@ -406,6 +408,10 @@ class FOFDataManagerLite():
                     if row.event_type in (FOFTradeStatus.PURCHASE, FOFTradeStatus.SUBSCRIBE):
                         assert not pd.isnull(row.amount), '!!!'
                         expenses += row.amount
+                        try:
+                            position_details[row.fund_id]['amount'] += row.amount
+                        except KeyError:
+                            position_details[row.fund_id] = {'start_date': date, 'amount': row.amount, 'dividend_cash': 0, 'redeem_amount': 0}
                     if row.event_type in (FOFTradeStatus.DEDUCT_REWARD, FOFTradeStatus.DIVIDEND_VOLUME, FOFTradeStatus.DEDUCT_REWARD_AND_DIVIDEND_VOLUME):
                         assert not pd.isnull(row.share), '!!!'
                         if row.event_type in (FOFTradeStatus.DIVIDEND_VOLUME, FOFTradeStatus.DEDUCT_REWARD_AND_DIVIDEND_VOLUME):
@@ -423,6 +429,8 @@ class FOFDataManagerLite():
                         fund_mv = self._get_fund_mv()
                     if row.event_type == FOFTradeStatus.DIVIDEND_CASH:
                         other_assets += row.amount
+                        assert row.fund_id in position_details, f'no pos of {row.fund_id} for DIVIDEND_CASH'
+                        position_details[row.fund_id]['dividend_cash'] += row.amount
                 assert other_assets >= expenses, f'no enough cash to buy asset!! (date){date} (total cash){total_cash}'
                 other_assets -= expenses
             except KeyError:
@@ -442,6 +450,8 @@ class FOFDataManagerLite():
                             self._fund_pos.loc[self._fund_pos.index >= date, row.fund_id] -= redemp_share
                             fund_mv = self._get_fund_mv()
                         other_assets += row.amount
+                        assert row.fund_id in position_details, f'no pos of {row.fund_id} for REDEEM'
+                        position_details[row.fund_id]['redeem_amount'] += row.amount
             except KeyError:
                 pass
 
@@ -520,9 +530,21 @@ class FOFDataManagerLite():
             	hedge_pos_info = None
 
             if fund_pos_info is not None or hedge_pos_info is not None:
-                position = pd.concat([fund_pos_info, hedge_pos_info], axis=0).rename_axis(index='fund_id').reset_index()
-                position = position[position.share != 0]
-                position['mv'] = position.share * position.nav
+                position = pd.concat([fund_pos_info, hedge_pos_info], axis=0).rename_axis(index='fund_id')
+                if not position.empty:
+                    position = position[position.share != 0]
+                    position['mv'] = position.share * position.nav
+                    position_details_the_date = pd.DataFrame.from_dict(position_details, orient='index').reindex(position.index)
+                    position['hold_date'] = (date - position_details_the_date.start_date).dt.days + 1
+                    position['total_ret'] = position.mv / position_details_the_date.amount - 1
+                    # if fund_nav.datetime.array[-1] > pur_sub_aa.confirmed_date.array[-1]:
+                    #     the_xirr = f'{round(xirr(pur_sub_aa.amount.to_list() + (-redempt_aa.amount).to_list() + [-mv], pur_sub_aa.datetime.to_list() + redempt_aa.datetime.to_list() + [fund_nav.datetime.array[-1]]) * 100, 2)}%'
+                    # else:
+                    #     the_xirr = np.nan
+                    # position['ann_ret'] = the_xirr
+                    position['ann_ret'] = (position.total_ret + 1).pow(FOFDataManagerLite._DAYS_PER_YEAR_FOR_INTEREST / position.hold_date) - 1
+                    # position['ann_ret_at']
+                    position = position.reset_index()
             else:
                 position = pd.Series().to_frame()
             positions_list.loc[date] = json.dumps(position.to_dict(orient='records'))
@@ -554,13 +576,15 @@ class FOFDataManagerLite():
             self._fof_nav['acc_net_value'] = self._fof_nav.nav
             self._fof_nav['adjusted_nav'] = self._fof_nav.nav
             self._fof_nav['ta_factor'] = 1
+            self._fof_nav['dy_per_share'] = np.nan
         else:
             dividend_cum = (dividend_record.acc_unit_value - dividend_record.net_asset_value)
-            dividend_sep = (dividend_cum - dividend_cum.shift(1, fill_value=0)).dropna().reindex(self._fof_nav.index, method='ffill')
+            self._fof_nav['dy_per_share'] = dividend_cum - dividend_cum.shift(1, fill_value=0).astype('float64')
+            dividend_sep = self._fof_nav.dy_per_share.dropna().reindex(self._fof_nav.index, method='ffill')
             self._fof_nav['acc_net_value'] = self._fof_nav.nav.add(dividend_sep, fill_value=0)
             adjusted_nav_and_ta_factor = HedgeFundDataManager.calc_whole_adjusted_net_value(self._fof_nav[['nav', 'acc_net_value']].rename(columns={'nav': 'net_asset_value', 'acc_net_value': 'acc_unit_value'}))
             self._fof_nav['adjusted_nav'], self._fof_nav['ta_factor'] = adjusted_nav_and_ta_factor['adj_nav'], adjusted_nav_and_ta_factor['adj_factor']
-
+        self._fof_nav['ta_factor'] = self._fof_nav.ta_factor.astype('float64')
         self._fof_nav['ret'] = self._fof_nav.adjusted_nav / self._fof_nav.adjusted_nav.array[0] - 1
         self._fof_nav = self._fof_nav.reset_index()
 
@@ -702,7 +726,7 @@ class FOFDataManagerLite():
             print('[dump_fof_nav_and_pos_to_db] no position detail, should calc it first')
 
         investor_return_df = FOFDataManagerLite().get_investor_return(manager_id=manager_id, fof_id=fof_id)
-        if investor_return_df is not None:
+        if investor_return_df is not None and not investor_return_df.empty:
             investor_return_df = investor_return_df.drop(columns=['total_rr']).rename(columns={'latest_mv': 'mv'})
             now_df = FOFDataManagerLite().get_fof_investor_position(manager_id, [fof_id])
             if now_df is not None:
@@ -797,26 +821,19 @@ class FOFDataManagerLite():
         # 客户赎回记录
         self._fof_redemp = fof_scale[fof_scale.event_type.isin([FOFTradeStatus.REDEEM, ])].set_index('datetime').sort_index()
         # fof_nav数据优先级更大
-        fof_nav = FOFDataManagerLite.get_fof_nav(manager_id=manager_id, fof_id=fof_id)
-        fof_nav_public = FOFDataManagerLite.get_fof_nav_public(manager_id=manager_id, fof_id=fof_id)
-        if fof_nav is None:
-            self._fof_nav = fof_nav_public
-        else:
-            if fof_nav_public is None:
-                self._fof_nav = fof_nav
-            else:
-                self._fof_nav = fof_nav.combine_first(fof_nav_public)
+        self._fof_nav = FOFDataManagerLite.get_fof_nav(manager_id, [fof_id])
         self._fof_nav['interest'] = np.nan
         self._fof_nav['management_fee'] = np.nan
         self._fof_nav['custodian_fee'] = np.nan
         self._fof_nav['administrative_fee'] = np.nan
+        self._fof_nav['dy_per_share'] = np.nan
         self.dump_fof_nav_and_pos_to_db(manager_id, fof_id, debug_mode)
 
     def _gather_asset_info_of_fof(self, manager_id, fof_id, fund_list: List[str], v_nav: pd.DataFrame):
         fof_aa = FOFDataManagerLite.get_fof_asset_allocation(manager_id, [fof_id])
-        hedge_nav = DerivedDataApi().get_fof_nav(manager_id, fund_list)
+        hedge_nav = FOFDataManagerLite.get_fof_nav(manager_id, fund_list)
         trading_day = BasicDataApi().get_trading_day_list(start_date=hedge_nav.datetime.min(), end_date=hedge_nav.datetime.max())
-        hedge_info = FOFDataManagerLite.get_hedge_fund_info(fund_list).set_index('fund_id')
+        hedge_info = BasicDataApi().get_fof_info(manager_id, fund_list).set_index('fof_id')
         for fund_id in fund_list:
             try:
                 fund_fof_aa = fof_aa.loc[fof_aa.fund_id == fund_id, :]
@@ -851,14 +868,14 @@ class FOFDataManagerLite():
                 latest_nav_date = fund_nav.loc[:, 'datetime'].iat[-1]
                 Session = sessionmaker(BasicDatabaseConnector().get_engine())
                 db_session = Session()
-                fof_info_to_set = db_session.query(HedgeFundInfo).filter(HedgeFundInfo.fund_id == fund_id).one_or_none()
+                fof_info_to_set = db_session.query(FOFInfo).filter((FOFInfo.manager_id == manager_id) & (FOFInfo.fof_id == fund_id)).one_or_none()
                 fof_info_to_set.latest_cal_date = latest_nav_date
                 fof_info_to_set.net_asset_value = float(fund_nav.nav.array[-1]) if not pd.isnull(fund_nav.nav.array[-1]) else None
                 fof_info_to_set.acc_unit_value = float(fund_nav.acc_net_value.array[-1]) if not pd.isnull(fund_nav.acc_net_value.array[-1]) else None
                 fof_info_to_set.adjusted_net_value = float(fund_nav.adjusted_nav.array[-1]) if not pd.isnull(fund_nav.adjusted_nav.array[-1]) else None
                 fof_info_to_set.mdd = float(res_status.mdd) if not pd.isnull(res_status.mdd) else None
-                fof_info_to_set.ret = float(total_ret) if not pd.isnull(total_ret) else None
-                fof_info_to_set.ann_ret = float(res_status.annualized_ret) if not pd.isnull(res_status.annualized_ret) else None
+                fof_info_to_set.ret_total = float(total_ret) if not pd.isnull(total_ret) else None
+                fof_info_to_set.ret_ann = float(res_status.annualized_ret) if not pd.isnull(res_status.annualized_ret) else None
                 db_session.commit()
                 db_session.close()
 
@@ -872,11 +889,12 @@ class FOFDataManagerLite():
                     ret_data_with_last_date['date'] = last_date_data.index.array[0]
                     ret_data_with_last_date['rr'] = f'{round(((fund_auv.array[-1] / last_date_data.array[0]) - 1) * 100, 2)}%'
 
-                fund_auv = fund_auv[fund_auv.index >= pur_sub_aa.sort_values(by='confirmed_date').confirmed_date.array[0]]
+                fund_auv = fund_auv[fund_auv.index >= pur_sub_aa.sort_values(by='datetime').datetime.array[0]]
                 if not fund_auv.empty:
+                    # TODO: 这里还没处理现金分红
                     res_status = Calculator.get_stat_result(fund_auv.index, fund_auv.array)
-                    mv = (pur_sub_aa.share.sum() - aa_insentive_info.share.sum() + aa_dividend_reinvestment.share.sum()) * fund_nav.nav.array[-1]
-                    real_mv = mv - redempt_aa.share.sum() * fund_nav.nav.array[-1]
+                    mv = (pur_sub_aa.share.sum() - aa_insentive_info.share.sum() + aa_dividend_reinvestment.share.sum() - redempt_aa.share.sum()) * fund_nav.nav.array[-1]
+                    real_mv = mv + redempt_aa.amount.sum()
                     total_cost = pur_sub_aa.amount.sum()
                     # v_net_value = fund_nav.v_net_value.array[-1]
                     # if not pd.isnull(v_net_value):
@@ -889,15 +907,15 @@ class FOFDataManagerLite():
                             v_net_value = '/'
                     else:
                         v_net_value = '/'
-                    if fund_nav.datetime.array[-1] > pur_sub_aa.confirmed_date.array[-1]:
-                        the_xirr = f'{round(xirr(pur_sub_aa.amount.to_list() + [-mv], pur_sub_aa.confirmed_date.to_list() + [fund_nav.datetime.array[-1]]) * 100, 2)}%'
+                    if fund_nav.datetime.array[-1] > pur_sub_aa.datetime.array[-1]:
+                        the_xirr = f'{round(xirr(pur_sub_aa.amount.to_list() + (-redempt_aa.amount).to_list() + [-mv], pur_sub_aa.datetime.to_list() + redempt_aa.datetime.to_list() + [fund_nav.datetime.array[-1]]) * 100, 2)}%'
                     else:
                         the_xirr = np.nan
                     holding_data = {
                         'start_date': res_status.start_date.isoformat(),
                         'days': (fund_auv.index.array[-1] - res_status.start_date).days,
-                        'mv': real_mv,
-                        'total_ret': f'{round((mv / total_cost - 1) * 100, 2)}%',
+                        'mv': mv,
+                        'total_ret': f'{round((real_mv / total_cost - 1) * 100, 2)}%',
                         'v_nav': v_net_value,
                         'avg_cost': round(total_cost / (pur_sub_aa.share.sum() - aa_insentive_info.share.sum()), 4),
                         'sharpe': round(res_status.sharpe, 6),
@@ -905,7 +923,7 @@ class FOFDataManagerLite():
                         'mdd': f'{round(res_status.mdd * 100, 2)}%',
                         'annualized_vol': f'{round(res_status.annualized_vol * 100, 2)}%',
                     }
-                    self._wechat_bot.send_hedge_fund_info(fof_id, fund_id, hedge_info.at[fund_id, 'brief_name'], latest_nav_date, fund_data, holding_data, ret_data_with_last_date, ret_date_with_last_pub)
+                    self._wechat_bot.send_hedge_fund_info(fof_id, fund_id, hedge_info.at[fund_id, 'desc_name'], latest_nav_date, fund_data, holding_data, ret_data_with_last_date, ret_date_with_last_pub)
             except Exception as e:
                 traceback.print_exc()
                 self._wechat_bot.send_hedge_fund_info_failed(fof_id, fund_id, e)
@@ -925,19 +943,20 @@ class FOFDataManagerLite():
         nav_df: Optional[pd.DataFrame] = hf_nav_r.read_navs_and_dump_to_db()
         if nav_df is not None:
             fund_list = list(nav_df.index.unique())
-            adj_nav = FOFDataManagerLite._calc_adjusted_net_value(manager_id, fund_list)
-            adj_nav = adj_nav[adj_nav.ta_factor.notna()]
-            if not adj_nav.empty:
-                print(adj_nav)
-                Session = sessionmaker(DerivedDatabaseConnector().get_engine())
-                db_session = Session()
-                for row in adj_nav.itertuples():
-                    fof_nav_to_set = db_session.query(FOFNav).filter(FOFNav.fof_id == row.Index, FOFNav.datetime == row.datetime).one_or_none()
-                    fof_nav_to_set.ta_factor = row.ta_factor
-                    fof_nav_to_set.adjusted_nav = row.adj_nav
-                    # fof_nav_to_set.change_rate = row.change_rate
-                    db_session.commit()
-                db_session.close()
+            # 这里先不用算复权净值了
+            # adj_nav = FOFDataManagerLite._calc_adjusted_net_value(manager_id, fund_list)
+            # adj_nav = adj_nav[adj_nav.ta_factor.notna()]
+            # if not adj_nav.empty:
+            #     print(adj_nav)
+            #     Session = sessionmaker(DerivedDatabaseConnector().get_engine())
+            #     db_session = Session()
+            #     for row in adj_nav.itertuples():
+            #         fof_nav_to_set = db_session.query(FOFNav).filter(FOFNav.manager_id == row.manager_id, FOFNav.fof_id == row.Index, FOFNav.datetime == row.datetime).one_or_none()
+            #         fof_nav_to_set.ta_factor = row.ta_factor
+            #         fof_nav_to_set.adjusted_nav = row.adj_nav
+            #         # fof_nav_to_set.change_rate = row.change_rate
+            #         db_session.commit()
+            #     db_session.close()
             # TODO: 这里先 hard code 一下
             if fof_id == 'SLW695':
                 v_nav = FOFDataManagerLite._calc_virtual_net_value(manager_id, fof_id, fund_list)
@@ -1012,37 +1031,37 @@ class FOFDataManagerLite():
         return BasicDataApi().get_fof_account_statement(manager_id, fof_id)
 
     @staticmethod
-    def get_fof_nav(manager_id: str, fof_id: str, *, ref_index_id: str = '', ref_fund_id: str = '') -> Optional[pd.DataFrame]:
-        fof_nav = DerivedDataApi().get_fof_nav(manager_id, [fof_id])
+    def get_fof_nav(manager_id: str, fof_id_list: Tuple[str] = (), *, ref_index_id: str = '', ref_fund_id: str = '') -> Optional[pd.DataFrame]:
+        fof_nav = DerivedDataApi().get_fof_nav(manager_id, fof_id_list)
+        fof_nav_public = FOFDataManagerLite.get_fof_nav_public(manager_id, fof_id_list)
         if fof_nav is None:
-            return
-        fof_nav = fof_nav.drop(columns=['update_time', 'create_time', 'is_deleted'])
-        if ref_index_id:
-            index_price = BasicDataApi().get_index_price(index_list=[ref_index_id])
-            if index_price is None or index_price.empty:
-                print(f'[get_fof_nav] get price of index {ref_index_id} failed (fof_id){fof_id}')
-                return fof_nav
-            return FOFDataManagerLite._concat_assets_price(fof_nav, index_price.drop(columns=['_update_time', 'index_id']).set_index('datetime')['close'])
-        elif ref_fund_id:
-            fund_nav = BasicDataApi().get_fund_nav_with_date(fund_list=[ref_fund_id])
-            if fund_nav is None or fund_nav.empty:
-                print(f'[get_fof_nav] get nav of fund {ref_fund_id} failed (fof_id){fof_id}')
-                return fof_nav
-            return FOFDataManagerLite._concat_assets_price(fof_nav, fund_nav.drop(columns='fund_id').set_index('datetime')['adjusted_net_value'])
+            fof_nav = fof_nav_public
         else:
-            return fof_nav
+            fof_nav = fof_nav.drop(columns=['update_time', 'create_time', 'is_deleted'])
+            if fof_nav_public is not None:
+                fof_nav = fof_nav.combine_first(fof_nav_public)
+        if fof_nav is not None:
+            if ref_index_id:
+                index_price = BasicDataApi().get_index_price(index_list=[ref_index_id])
+                if index_price is None or index_price.empty:
+                    print(f'[get_fof_nav] get price of index {ref_index_id} failed (fof_id_list){fof_id_list}')
+                    return fof_nav
+                return FOFDataManagerLite._concat_assets_price(fof_nav, index_price.drop(columns=['_update_time', 'index_id']).set_index('datetime')['close'])
+            elif ref_fund_id:
+                fund_nav = BasicDataApi().get_fund_nav_with_date(fund_list=[ref_fund_id])
+                if fund_nav is None or fund_nav.empty:
+                    print(f'[get_fof_nav] get nav of fund {ref_fund_id} failed (fof_id_list){fof_id_list}')
+                    return fof_nav
+                return FOFDataManagerLite._concat_assets_price(fof_nav, fund_nav.drop(columns='fund_id').set_index('datetime')['adjusted_net_value'])
+        return fof_nav
 
     @staticmethod
-    def get_fof_nav_public(manager_id: str, fof_id: str) -> Optional[pd.DataFrame]:
-        fof_nav = DerivedDataApi().get_fof_nav_public(manager_id, [fof_id])
+    def get_fof_nav_public(manager_id: str, fof_id: Tuple[str] = ()) -> Optional[pd.DataFrame]:
+        fof_nav = DerivedDataApi().get_fof_nav_public(manager_id, fof_id)
         if fof_nav is None:
             return
         return fof_nav.drop(columns=['update_time', 'create_time', 'is_deleted'])
 
-    @staticmethod
-    def get_hedge_fund_info(fund_id: Tuple[str] = ()):
-        return BasicDataApi().get_hedge_fund_info(fund_id)
-
     @staticmethod
     def get_hedge_fund_nav(fund_id: Tuple[str] = ()):
         df = BasicDataApi().get_hedge_fund_nav(fund_id)
@@ -1052,7 +1071,7 @@ class FOFDataManagerLite():
 
     @staticmethod
     def get_investor_pos_summary(manager_id: str):
-        fof_nav = DerivedDataApi().get_fof_nav(manager_id)
+        fof_nav = FOFDataManagerLite.get_fof_nav(manager_id)
         if fof_nav is None or fof_nav.empty:
             return
         fof_scale_info = DerivedDataApi().get_hedge_fund_investor_pur_redemp(manager_id)
@@ -1105,6 +1124,8 @@ class FOFDataManagerLite():
             whole_df = pd.concat([mv.rename('mv'), amount.rename('amount'), left_amount.rename('left_amount'), share_sum.rename('shares'), left_share_sum.rename('left_shares'), total_ret.rename('total_ret'), total_rr.rename('total_rr')], axis=1)
             whole_df['investor_id'] = investor_id
             result_df_list.append(whole_df)
+        if not result_df_list:
+            return
         df = pd.concat(result_df_list, axis=0).reset_index()
         df = df[df.amount != 0]
         df['manager_id'] = manager_id
@@ -1113,7 +1134,7 @@ class FOFDataManagerLite():
     @staticmethod
     def get_investor_return(manager_id: str, fof_id: str, *, investor_id_list: Tuple[str] = (), start_date: Optional[datetime.date] = None, end_date: Optional[datetime.date] = None) -> Optional[pd.DataFrame]:
         '''计算投资者收益'''
-        fof_nav = DerivedDataApi().get_fof_nav(manager_id, [fof_id])
+        fof_nav = FOFDataManagerLite.get_fof_nav(manager_id, [fof_id])
         if fof_nav is None:
             return
         fof_nav = fof_nav.set_index('datetime')
@@ -1220,7 +1241,7 @@ class FOFDataManagerLite():
         fof_info: Optional[pd.DataFrame] = FOFDataManagerLite.get_fof_info(manager_id, [fof_id])
         if fof_info is None:
             return
-        fof_nav = DerivedDataApi().get_fof_nav(manager_id, [fof_id])
+        fof_nav = FOFDataManagerLite.get_fof_nav(manager_id, [fof_id])
         if fof_nav is None:
             return
         try:
@@ -1244,10 +1265,10 @@ class FOFDataManagerLite():
         try:
             # 下边这个分支是从私募排排网上多只私募基金净值数据的文件中读取数据
             # if file_type == 'csv':
-            #     hedge_fund_info = BasicDataApi().get_hedge_fund_info()
+            #     hedge_fund_info = BasicDataApi().get_fof_nav(datas['manager_id'])
             #     if hedge_fund_info is None:
             #         return
-            #     fund_name_map = hedge_fund_info.set_index('brief_name')['fund_id'].to_dict()
+            #     fund_name_map = hedge_fund_info.set_index('desc_name')['fof_id'].to_dict()
             #     fund_name_map['日期'] = 'datetime'
             #     df = pd.read_csv(io.BytesIO(datas), encoding='gbk')
             #     lacked_map = set(df.columns.array) - set(fund_name_map.keys())
@@ -1277,9 +1298,9 @@ class FOFDataManagerLite():
                     return False
                 else:
                     df = df.rename(columns=HedgeFundNAVReader.COLUMNS_DICT)
-                    df['fund_id'] = hedge_fund_id
+                    df['fof_id'] = hedge_fund_id
 
-            df = df[df.drop(columns=['fund_id', 'datetime']).notna().any(axis=1)]
+            df = df[df.drop(columns=['fof_id', 'datetime']).notna().any(axis=1)]
             now_df = BasicDataApi().get_hedge_fund_nav([hedge_fund_id])
             if now_df is not None:
                 now_df = now_df.drop(columns=['update_time', 'create_time', 'insert_time', 'is_deleted', 'calc_date']).astype({'net_asset_value': 'float64', 'acc_unit_value': 'float64', 'v_net_value': 'float64', 'adjusted_net_value': 'float64'})
@@ -1332,7 +1353,7 @@ class FOFDataManagerLite():
         return positions, mvs, navs
 
     @staticmethod
-    def virtual_backtest(hedge_fund_ids: Dict[str, float], ref_fund_ids: Dict[str, str], start_date: datetime.date, end_date: Optional[datetime.date] = None, benchmark_ids: Tuple[str] = ()) -> Optional[Tuple[pd.DataFrame, pd.DataFrame, pd.DataFrame, List[str]]]:
+    def virtual_backtest(manager_id: str, hedge_fund_ids: Dict[str, float], ref_fund_ids: Dict[str, str], start_date: datetime.date, end_date: Optional[datetime.date] = None, benchmark_ids: Tuple[str] = ()) -> Optional[Tuple[pd.DataFrame, pd.DataFrame, pd.DataFrame, List[str]]]:
         '''
         对私募基金做虚拟回测
 
@@ -1361,21 +1382,21 @@ class FOFDataManagerLite():
             if end_date is None:
                 end_date = datetime.date.today()
             # 获取必要的私募基金信息
-            fund_info = BasicDataApi().get_hedge_fund_info(list(hedge_fund_ids.keys()))
+            fund_info = BasicDataApi().get_fof_info(manager_id, list(hedge_fund_ids.keys()))
             if fund_info is None:
                 return
-            fund_info = fund_info.set_index('fund_id')
+            fund_info = fund_info.set_index('fof_id')
 
             # 统计一下需要替代的基金的ref ids
             funds_added = [ref for fund, ref in ref_fund_ids.items() if fund in hedge_fund_ids.keys()]
             # 获取私募基金净值数据
-            fund_nav = FOFDataManagerLite.get_hedge_fund_nav(list(hedge_fund_ids.keys()) + funds_added)
+            fund_nav = FOFDataManagerLite.get_fof_nav(manager_id, list(hedge_fund_ids.keys()) + funds_added)
             if fund_nav is None:
                 return
 
             # 这里首选复权净值
-            fund_nav = fund_nav[(fund_nav.fund_id != 'SR9762') | (fund_nav.datetime >= pd.to_datetime('2020-07-01', infer_datetime_format=True).date())]
-            adj_nav = fund_nav.pivot(index='datetime', columns='fund_id', values='adjusted_net_value')
+            fund_nav = fund_nav[(fund_nav.fof_id != 'SR9762') | (fund_nav.datetime >= pd.to_datetime('2020-07-01', infer_datetime_format=True).date())]
+            adj_nav = fund_nav.pivot(index='datetime', columns='fof_id', values='adjusted_nav')
             # 处理ref fund
             for fund, ref in ref_fund_ids.items():
                 org_nav = adj_nav[fund]
@@ -1395,7 +1416,7 @@ class FOFDataManagerLite():
             if adj_nav_lacked:
                 # TODO 如果某只基金完全没有复权净值 需要用累计净值来计算
                 # FIXME 这里不能直接用数据库里存的虚拟净值 因为这个是邮件里发过来的单位净值虚拟后净值 而上边算出来的是复权净值虚拟后净值
-                acc_nav = fund_nav[fund_nav.fund_id.isin(adj_nav_lacked)].pivot(index='datetime', columns='fund_id', values='acc_unit_value')
+                acc_nav = fund_nav[fund_nav.fof_id.isin(adj_nav_lacked)].pivot(index='datetime', columns='fof_id', values='acc_net_value')
                 adj_nav = adj_nav.drop(columns=adj_nav_lacked).join(acc_nav, how='outer')
             fund_info = fund_info.reindex(adj_nav.columns)
             lacked_funds = list(set(hedge_fund_ids.keys()) - set(adj_nav.columns.array))
@@ -1404,7 +1425,8 @@ class FOFDataManagerLite():
 
             # 计算虚拟净值
             FOFDataManagerLite._adj_nav = adj_nav
-            fund_nav = FOFDataManagerLite._do_calc_v_net_value_by_nav(adj_nav, adj_nav, adj_nav.loc[adj_nav.index >= start_date, :].bfill().iloc[0, :], fund_info.incentive_fee_ratio.fillna(DEFAULT_INCENTIVE_RATIO), fund_info.v_nav_decimals.fillna(DEFAULT_DECIMAL))
+            # TODO: incentive_fee_str需要根据incentive_fee_type来使用
+            fund_nav = FOFDataManagerLite._do_calc_v_net_value_by_nav(adj_nav, adj_nav, adj_nav.loc[adj_nav.index >= start_date, :].bfill().iloc[0, :], fund_info.incentive_fee_str.fillna(DEFAULT_INCENTIVE_RATIO), fund_info.v_nav_decimals.fillna(DEFAULT_DECIMAL))
             # water_line = pd.Series({'SGM473': 1, 'SGM992': 1, 'SJE335': 1, 'SLC213': 1, 'SNG191': 1, 'SNH765': 1, 'SR9762': 1.1146})
             # fund_nav = FOFDataManagerLite._do_calc_v_net_value_by_nav(adj_nav, adj_nav, water_line, fund_info.incentive_fee_ratio.fillna(DEFAULT_INCENTIVE_RATIO), fund_info.v_nav_decimals.fillna(DEFAULT_DECIMAL))
             # fund_nav = FOFDataManagerLite._do_calc_v_net_value_by_nav(adj_nav, adj_nav, fund_info.water_line.fillna(INIT_NAV), fund_info.incentive_fee_ratio.fillna(DEFAULT_INCENTIVE_RATIO), fund_info.v_nav_decimals.fillna(DEFAULT_DECIMAL))
@@ -1473,7 +1495,7 @@ class FOFDataManagerLite():
             return
 
     @staticmethod
-    def virtual_backtest_sub(hedge_fund_ids: Dict[str, str], start_date: datetime.date, end_date: Optional[datetime.date] = None) -> Optional[Tuple[pd.DataFrame, pd.DataFrame, pd.DataFrame, List[str]]]:
+    def virtual_backtest_sub(manager_id: str, hedge_fund_ids: Dict[str, str], start_date: datetime.date, end_date: Optional[datetime.date] = None) -> Optional[Tuple[pd.DataFrame, pd.DataFrame, pd.DataFrame, List[str]]]:
         DEFAULT_INCENTIVE_RATIO = 0.2
         DEFAULT_DECIMAL = 4
         INIT_NAV = 1
@@ -1482,17 +1504,17 @@ class FOFDataManagerLite():
             if end_date is None:
                 end_date = datetime.date.today()
             # 获取必要的私募基金信息
-            fund_info = BasicDataApi().get_hedge_fund_info(list(hedge_fund_ids.keys()))
+            fund_info = BasicDataApi().get_fof_info(manager_id, list(hedge_fund_ids.keys()))
             if fund_info is None:
                 return
-            fund_info = fund_info.set_index('fund_id')
+            fund_info = fund_info.set_index('fof_id')
 
             # 获取私募基金净值数据
-            fund_nav = FOFDataManagerLite.get_hedge_fund_nav(list(hedge_fund_ids.keys()))
+            fund_nav = FOFDataManagerLite.get_fof_nav(manager_id, list(hedge_fund_ids.keys()))
             if fund_nav is None:
                 return
             # 这里首选复权净值
-            adj_nav = fund_nav.pivot(index='datetime', columns='fund_id', values='adjusted_net_value')
+            adj_nav = fund_nav.pivot(index='datetime', columns='fof_id', values='adjusted_nav')
             # 去掉全是nan的列
             valid_adj_nav = adj_nav.loc[:, adj_nav.notna().any(axis=0)]
             # 计算缺少的列
@@ -1500,7 +1522,7 @@ class FOFDataManagerLite():
             if adj_nav_lacked:
                 # TODO 如果某只基金完全没有复权净值 需要用累计净值来计算
                 # FIXME 这里不能直接用数据库里存的虚拟净值 因为这个是邮件里发过来的单位净值虚拟后净值 而上边算出来的是复权净值虚拟后净值
-                acc_nav = fund_nav[fund_nav.fund_id.isin(adj_nav_lacked)].pivot(index='datetime', columns='fund_id', values='acc_unit_value')
+                acc_nav = fund_nav[fund_nav.fof_id.isin(adj_nav_lacked)].pivot(index='datetime', columns='fof_id', values='acc_net_value')
                 adj_nav = adj_nav.join(acc_nav, how='outer')
             fund_info = fund_info.reindex(adj_nav.columns)
             lacked_funds = list(set(hedge_fund_ids.keys()) - set(adj_nav.columns.array))
@@ -1508,7 +1530,9 @@ class FOFDataManagerLite():
                 del hedge_fund_ids[one]
 
             # 计算虚拟净值
-            fund_nav = FOFDataManagerLite._do_calc_v_net_value_by_nav(adj_nav, adj_nav, fund_info.water_line.fillna(INIT_NAV), fund_info.incentive_fee_ratio.fillna(DEFAULT_INCENTIVE_RATIO), fund_info.v_nav_decimals.fillna(DEFAULT_DECIMAL))
+            # TODO: water_line不在这里了 需要改一下的
+            # TODO: incentive_fee_str需要根据incentive_fee_type来处理
+            fund_nav = FOFDataManagerLite._do_calc_v_net_value_by_nav(adj_nav, adj_nav, fund_info.water_line.fillna(INIT_NAV), fund_info.incentive_fee_str.fillna(DEFAULT_INCENTIVE_RATIO), fund_info.v_nav_decimals.fillna(DEFAULT_DECIMAL))
 
             trading_day = BasicDataApi().get_trading_day_list(start_date=fund_nav.index.array[0], end_date=fund_nav.index.array[-1])
             trading_day = trading_day[trading_day.datetime.between(start_date, end_date)]
