@@ -565,10 +565,10 @@ class HedgeFundDataManager(metaclass=Singleton):
             'hedge_funds_data': hedge_funds.to_json(orient='records'),
         })
         total_df = total_df.to_frame().T
-        total_df = total_df.infer_objects()
+        # total_df = total_df.infer_objects()
         now_df = DerivedDataApi().get_hedge_fund_custodian_data(manager_id=manager_id, fof_id_list=[fof_id])
         if now_df is not None:
-            now_df = now_df.drop(columns=['update_time', 'create_time', 'is_deleted']).astype(total_df.dtypes.to_dict())
+            now_df = now_df.drop(columns=['update_time', 'create_time', 'is_deleted']).replace({None: np.nan}).astype(total_df.dtypes.to_dict())
             # merge on all columns
             df = total_df.round(6).merge(now_df.round(6), how='left', indicator=True, validate='one_to_one')
             df = df[df._merge == 'left_only'].drop(columns=['_merge'])
@@ -591,8 +591,8 @@ class HedgeFundDataManager(metaclass=Singleton):
         nav_acc_data : pd.DataFrame
             净值数据, index: datetime.date 净值日期
                 columns:
-                    net_asset_value : 单位净值(必须从1开始)
-                    acc_unit_value : 累计净值(必须从1开始)
+                    net_asset_value : 单位净值(必须从1开始, 除非与累计净值完全相同)
+                    acc_unit_value : 累计净值(必须从1开始, 除非与单位净值完全相同)
 
         Returns/Exceptions
         -------
@@ -603,10 +603,20 @@ class HedgeFundDataManager(metaclass=Singleton):
                 columns:
                     adj_nav : 复权净值
                     adj_factor: 复权因子
+                    change_rate: 涨跌幅
         '''
 
         # 先按index(datetime.date)排序
         nav_acc_data: pd.DataFrame = nav_acc_data.sort_index()
+        if nav_acc_data.net_asset_value.equals(nav_acc_data.acc_unit_value):
+            # 如果单位净值和累计净值完全一样 允许不从1开始 走一个单独的(简易)计算流程
+            df = nav_acc_data
+            df['adj_nav'] = df.net_asset_value
+            df['change_rate'] = df.adj_nav.pct_change()
+            df['adj_factor'] = 1
+            df = df[['adj_nav', 'adj_factor', 'change_rate']]
+            return df
+
         assert math.isclose(nav_acc_data.net_asset_value.array[0], 1) and math.isclose(nav_acc_data.acc_unit_value.array[0], 1), f'fund nav data should start with 1 (data){nav_acc_data}'
 
         assert nav_acc_data.acc_unit_value.round(6).ge(nav_acc_data.net_asset_value.round(6)).all(), f'acc_unit_value should always ge than net_asset_value (data){nav_acc_data}'
@@ -620,5 +630,6 @@ class HedgeFundDataManager(metaclass=Singleton):
 
         df: pd.DataFrame = adj_factor.reindex(nav_acc_data.index, method='bfill').to_frame('adj_factor')
         df['adj_nav'] = df.adj_factor * nav_acc_data.net_asset_value
-        df = df[['adj_nav', 'adj_factor']]
+        df['change_rate'] = df.adj_nav.pct_change()
+        df = df[['adj_nav', 'adj_factor', 'change_rate']]
         return df
