@@ -903,9 +903,8 @@ class FOFInfo(FOFBase):
     administrative_fee = Column(DOUBLE(asdecimal=False), nullable=False)  # 行政管理费率
     lock_up_period = Column(TEXT)  # 锁定期
     incentive_fee_mode = Column(VARCHAR(31))  # 业绩报酬计提方法
-    incentive_fee = Column(VARCHAR(127))  # 业绩报酬提取比例
-    incentive_fee_type = Column(VARCHAR(31))
-    incentive_fee_str = Column(VARCHAR(255))
+    incentive_fee_type = Column(VARCHAR(31))  # 业绩报酬计提类型
+    incentive_fee_str = Column(VARCHAR(255))  # 业绩报酬提取规则
     current_deposit_rate = Column(DOUBLE(asdecimal=False))  # 银行活期存款利率
     initial_raised_fv = Column(DOUBLE(asdecimal=False))  # 初始募集面值
     initial_net_value = Column(DOUBLE(asdecimal=False))  # 期初总资产净值
@@ -921,7 +920,7 @@ class FOFInfo(FOFBase):
     sharpe = Column(DOUBLE(asdecimal=False))                # 夏普比率
     vol = Column(DOUBLE(asdecimal=False))                   # 波动率
     is_calculating = Column(BOOLEAN, default=False)         # 是否正在计算
-    latest_cal_date = Column(DATETIME)                      # 最新净值日
+    latest_cal_date = Column(DATE)                          # 最新净值日
     strategy_type = Column(Integer)                         # 策略类型
     sub_strategy_type = Column(VARCHAR(31))                 # 子策略类型
     risk_type = Column(Integer)                             # 风险等级
@@ -930,6 +929,7 @@ class FOFInfo(FOFBase):
     is_top = Column(BOOLEAN, default=False)                 # 是否置顶
     benchmark = Column(VARCHAR(63))                         # 默认业绩基准
     asset_type = Column(VARCHAR(63))                        # 产品类型
+    nav_decimals = Column(SMALLINT)                         # 净值精度
     nav_freq = Column(VARCHAR(31))                          # 净值频率
     fund_no = Column(CHAR(6))                               # 基金编号
     management_ids = Column(VARCHAR(255))                   # 所属机构ID
@@ -943,6 +943,7 @@ class FOFInfo(FOFBase):
     fof_manager = Column(VARCHAR(16))                       # 基金经理
     benchmark_index = Column(VARCHAR(127))                  # 基准指数
     open_date = Column(CHAR(63))                            # 开放日
+    stars = Column(Integer, server_default=text('1'))       # 星级
 
 
 class FOFScaleAlteration(FOFBase):
