@@ -112,6 +112,21 @@ class CalculatorBase:
         continue_regress_v = res.params[0]
         return continue_regress_v
 
+    @staticmethod
+    def calc_modify_annual_vol(sr: pd.core.series.Series):
+        # 每个ret(i)除以产生它的时长平方根sqrt(T(i))后，服从独立同分布，可以用来估计日波动率，最后再乘以sqrt(242)年化
+        dts = BasicDataApi().get_trading_day_list(start_date=sr.index[0], end_date=sr.index[-1]).set_index('datetime')
+        sr_ret = sr.pct_change(1)
+        sr_ret.name = 'ret'
+        sr_ret.index.name = 'this_day'
+        sr_ret = sr_ret.reset_index()
+        sr_ret.loc[:,'last_day'] = sr_ret.this_day.shift(1)
+        sr_ret = sr_ret.dropna()
+        sr_ret.loc[:,'trade_dates'] = sr_ret.apply(lambda x: dts.loc[x.last_day:x.this_day].shape[0], axis=1)
+        sr_ret.loc[:,'modify_ret'] = sr_ret.ret / np.sqrt(sr_ret.trade_dates)
+        annual_vol = sr_ret.modify_ret.std(ddof=1) * np.sqrt(CalculatorBase.TRADING_DAYS_PER_YEAR)
+        return annual_vol
+
     @staticmethod
     def calc_recent_ret(dates:             pd.core.series.Series,
                         values:            pd.core.series.Series,
@@ -365,9 +380,6 @@ class CalculatorBase:
                 period_6m = period_1m * 6
                 period_1y = CalculatorBase.TRADING_DAYS_PER_YEAR
                 risk_free_per_period = risk_free_rate / CalculatorBase.TRADING_DAYS_PER_YEAR
-                dts = BasicDataApi().get_trading_day_list(start_date=sr.index[0], end_date=sr.index[-1]).datetime
-                sr_annual_vol = sr.reindex(sr.index.union(dts)).sort_index().ffill().reindex(dts)
-                sr_ret_annual_vol = sr_annual_vol.pct_change(1).iloc[1:]
             elif frequency == '1W':
                 period_1m = 4
                 period_3m = period_1m * 3
@@ -397,10 +409,7 @@ class CalculatorBase:
             cumu_ret = last_unit_nav - 1
             trade_year = days / CalculatorBase.TOTAL_DAYS_PER_YEAR
             annual_ret = math.pow(last_unit_nav, CalculatorBase.TOTAL_DAYS_PER_YEAR/days) - 1
-            if frequency == '1D':
-                annual_vol = sr_ret_annual_vol.std(ddof=1) * np.sqrt(period_1y)
-            else:
-                annual_vol = sr.pct_change(1).iloc[1:].std(ddof=1) * np.sqrt(period_1y)
+            annual_vol = CalculatorBase.calc_modify_annual_vol(sr)
             _begin_date = sr.index[0]
             recent_ret_res = CalculatorBase.calc_recent_ret(dates=dates,values=values,frequency='1D')
             recent_year_ret = recent_ret_res['recent_natural_year_ret']
